@@ -191,7 +191,17 @@ namespace TagLib.Tests.TaggingFormats
 				});
 			}
 		}
-		
+
+		[Test]
+		public void TestComment4Bytes ()
+		{
+			// Comment data found in the wild, see bgo#607376
+			var data = new byte[] { 67, 79, 77, 77, 0, 0, 0, 4, 0, 0, 0, 203, 0, 255 };
+			var frame = new CommentsFrame (data, 3);
+			Assert.IsEmpty (frame.Description);
+			Assert.IsEmpty (frame.Text);
+		}
+
 		[Test]
 		public void TestGenres ()
 		{
@@ -591,6 +601,286 @@ namespace TagLib.Tests.TaggingFormats
 			}
 		}
 		
+		[Test]
+		public void TestMusicBrainzArtistID ()
+		{
+			Id3v2.Tag tag = new Id3v2.Tag ();
+			for (byte version = 2; version <= 4; version ++) {
+				tag.Version = version;
+
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsTrue (t.IsEmpty, "Initial (IsEmpty): " + m);
+				Assert.IsNull (t.MusicBrainzArtistId, "Initial (Null): " + m);
+				});
+			
+			tag.MusicBrainzArtistId = val_sing;
+			
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsFalse (t.IsEmpty, "Value Set (!IsEmpty): " + m);
+				Assert.AreEqual (val_sing, t.MusicBrainzArtistId, "Value Set (!Null): " + m);
+				});
+			
+			tag.MusicBrainzArtistId = string.Empty;
+
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsTrue (t.IsEmpty, "Value Cleared (IsEmpty): " + m);
+				Assert.IsNull (t.MusicBrainzArtistId, "Value Cleared (Null): " + m);
+				});	
+			}
+		}
+		
+		[Test]
+		public void TestMusicBrainzReleaseID ()
+		{
+			Id3v2.Tag tag = new Id3v2.Tag ();
+			for (byte version = 2; version <= 4; version ++) {
+				tag.Version = version;
+
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsTrue (t.IsEmpty, "Initial (IsEmpty): " + m);
+				Assert.IsNull (t.MusicBrainzReleaseId, "Initial (Null): " + m);
+				});
+			
+			tag.MusicBrainzReleaseId = val_sing;
+			
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsFalse (t.IsEmpty, "Value Set (!IsEmpty): " + m);
+				Assert.AreEqual (val_sing, t.MusicBrainzReleaseId, "Value Set (!Null): " + m);
+				});
+			
+			tag.MusicBrainzReleaseId = string.Empty;
+
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsTrue (t.IsEmpty, "Value Cleared (IsEmpty): " + m);
+				Assert.IsNull (t.MusicBrainzReleaseId, "Value Cleared (Null): " + m);
+				});
+			}
+		}
+		
+		[Test]
+		public void TestMusicBrainzReleaseArtistID ()
+		{
+			Id3v2.Tag tag = new Id3v2.Tag ();
+			for (byte version = 2; version <= 4; version ++) {
+				tag.Version = version;
+
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsTrue (t.IsEmpty, "Initial (IsEmpty): " + m);
+				Assert.IsNull (t.MusicBrainzReleaseArtistId, "Initial (Null): " + m);
+				});
+			
+			tag.MusicBrainzReleaseArtistId = val_sing;
+			
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsFalse (t.IsEmpty, "Value Set (!IsEmpty): " + m);
+				Assert.AreEqual (val_sing, t.MusicBrainzReleaseArtistId, "Value Set (!Null): " + m);
+				});
+			
+			tag.MusicBrainzReleaseArtistId = string.Empty;
+
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsTrue (t.IsEmpty, "Value Cleared (IsEmpty): " + m);
+				Assert.IsNull (t.MusicBrainzReleaseArtistId, "Value Cleared (Null): " + m);
+				});
+			}
+		}
+		
+		[Test]
+		public void TestMusicBrainzTrackID ()
+		{
+			Id3v2.Tag tag = new Id3v2.Tag ();
+			for (byte version = 2; version <= 4; version ++) {
+				tag.Version = version;
+
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsTrue (t.IsEmpty, "Initial (IsEmpty): " + m);
+				Assert.IsNull (t.MusicBrainzTrackId, "Initial (Null): " + m);
+				});
+			
+			tag.MusicBrainzTrackId = val_sing;
+			
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsFalse (t.IsEmpty, "Value Set (!IsEmpty): " + m);
+				Assert.AreEqual (val_sing, t.MusicBrainzTrackId, "Value Set (!Null): " + m);
+				});
+			
+			tag.MusicBrainzTrackId = string.Empty;
+
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsTrue (t.IsEmpty, "Value Cleared (IsEmpty): " + m);
+				Assert.IsNull (t.MusicBrainzTrackId, "Value Cleared (Null): " + m);
+				});
+			}
+		}
+		
+		[Test]
+		public void TestMusicBrainzDiscID ()
+		{
+			Id3v2.Tag tag = new Id3v2.Tag ();
+			for (byte version = 2; version <= 4; version ++) {
+				tag.Version = version;
+
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsTrue (t.IsEmpty, "Initial (IsEmpty): " + m);
+				Assert.IsNull (t.MusicBrainzDiscId, "Initial (Null): " + m);
+				});
+			
+			tag.MusicBrainzDiscId = val_sing;
+			
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsFalse (t.IsEmpty, "Value Set (!IsEmpty): " + m);
+				Assert.AreEqual (val_sing, t.MusicBrainzDiscId, "Value Set (!Null): " + m);
+				});
+			
+			tag.MusicBrainzDiscId = string.Empty;
+
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsTrue (t.IsEmpty, "Value Cleared (IsEmpty): " + m);
+				Assert.IsNull (t.MusicBrainzDiscId, "Value Cleared (Null): " + m);
+				});
+			}
+		}
+		
+		[Test]
+		public void TestMusicIPPUID ()
+		{
+			Id3v2.Tag tag = new Id3v2.Tag ();
+			for (byte version = 2; version <= 4; version ++) {
+				tag.Version = version;
+
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsTrue (t.IsEmpty, "Initial (IsEmpty): " + m);
+				Assert.IsNull (t.MusicIpId, "Initial (Null): " + m);
+				});
+			
+			tag.MusicIpId = val_sing;
+			
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsFalse (t.IsEmpty, "Value Set (!IsEmpty): " + m);
+				Assert.AreEqual (val_sing, t.MusicIpId, "Value Set (!Null): " + m);
+				});
+			
+			tag.MusicIpId = string.Empty;
+
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsTrue (t.IsEmpty, "Value Cleared (IsEmpty): " + m);
+				Assert.IsNull (t.MusicIpId, "Value Cleared (Null): " + m);
+				});
+			}
+		}
+		
+		[Test]
+		public void TestAmazonID ()
+		{
+			Id3v2.Tag tag = new Id3v2.Tag ();
+			for (byte version = 2; version <= 4; version ++) {
+				tag.Version = version;
+
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsTrue (t.IsEmpty, "Initial (IsEmpty): " + m);
+				Assert.IsNull (t.AmazonId, "Initial (Null): " + m);
+				});
+			
+			tag.AmazonId = val_sing;
+			
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsFalse (t.IsEmpty, "Value Set (!IsEmpty): " + m);
+				Assert.AreEqual (val_sing, t.AmazonId, "Value Set (!Null): " + m);
+				});
+				
+			tag.AmazonId = string.Empty;
+
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsTrue (t.IsEmpty, "Value Cleared (IsEmpty): " + m);
+				Assert.IsNull (t.AmazonId, "Value Cleared (Null): " + m);
+				});
+			}
+		}
+				
+		[Test]
+		public void TestMusicBrainzReleaseStatus ()
+		{
+			Id3v2.Tag tag = new Id3v2.Tag ();
+			for (byte version = 2; version <= 4; version ++) {
+				tag.Version = version;
+
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsTrue (t.IsEmpty, "Initial (IsEmpty): " + m);
+				Assert.IsNull (t.MusicBrainzReleaseStatus, "Initial (Null): " + m);
+				});
+			
+			tag.MusicBrainzReleaseStatus = val_sing;
+			
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsFalse (t.IsEmpty, "Value Set (!IsEmpty): " + m);
+				Assert.AreEqual (val_sing, t.MusicBrainzReleaseStatus, "Value Set (!Null): " + m);
+				});
+			
+			tag.MusicBrainzReleaseStatus = string.Empty;
+
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsTrue (t.IsEmpty, "Value Cleared (IsEmpty): " + m);
+				Assert.IsNull (t.MusicBrainzReleaseStatus, "Value Cleared (Null): " + m);
+				});
+			}
+		}
+				
+		[Test]
+		public void TestMusicBrainzReleaseType ()
+		{
+			Id3v2.Tag tag = new Id3v2.Tag ();
+			for (byte version = 2; version <= 4; version ++) {
+				tag.Version = version;
+
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsTrue (t.IsEmpty, "Initial (IsEmpty): " + m);
+				Assert.IsNull (t.MusicBrainzReleaseType, "Initial (Null): " + m);
+				});
+			
+			tag.MusicBrainzReleaseType = val_sing;
+			
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsFalse (t.IsEmpty, "Value Set (!IsEmpty): " + m);
+				Assert.AreEqual (val_sing, t.MusicBrainzReleaseType, "Value Set (!Null): " + m);
+				});
+			
+			tag.MusicBrainzReleaseType = string.Empty;
+
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsTrue (t.IsEmpty, "Value Cleared (IsEmpty): " + m);
+				Assert.IsNull (t.MusicBrainzReleaseType, "Value Cleared (Null): " + m);
+				});
+			}
+		}
+				
+		[Test]
+		public void TestMusicBrainzReleaseCountry ()
+		{
+			Id3v2.Tag tag = new Id3v2.Tag ();
+			for (byte version = 2; version <= 4; version ++) {
+				tag.Version = version;
+
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsTrue (t.IsEmpty, "Initial (IsEmpty): " + m);
+				Assert.IsNull (t.MusicBrainzReleaseCountry, "Initial (Null): " + m);
+				});
+			
+			tag.MusicBrainzReleaseCountry = val_sing;
+			
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsFalse (t.IsEmpty, "Value Set (!IsEmpty): " + m);
+				Assert.AreEqual (val_sing, t.MusicBrainzReleaseCountry, "Value Set (!Null): " + m);
+				});
+			
+			tag.MusicBrainzReleaseCountry = string.Empty;
+
+			TagTestWithSave (ref tag, delegate (Id3v2.Tag t, string m) {
+				Assert.IsTrue (t.IsEmpty, "Value Cleared (IsEmpty): " + m);
+				Assert.IsNull (t.MusicBrainzReleaseCountry, "Value Cleared (Null): " + m);
+				});
+			}
+		}
+		
 		[Test]
 		public void TestClear ()
 		{
@@ -917,7 +1207,18 @@ namespace TagLib.Tests.TaggingFormats
 			
 			}}}}}}}}}
 		}
-		
+
+		[Test]
+		public void TestRelativeVolumeFrameWithBrokenPeakVolume ()
+		{
+			// RVA2 data found in the wild
+			var data = new byte[] { 82, 86, 65, 50, 0, 0, 0, 12, 0, 0, 97, 108, 98, 117, 109, 0, 1, 255, 0, 200, 15, 116 };
+			var frame = new RelativeVolumeFrame (data, 4);
+			Assert.AreEqual ("album", frame.Identification);
+			Assert.AreEqual (-256, frame.GetVolumeAdjustmentIndex (ChannelType.MasterVolume));
+			Assert.AreEqual (0, frame.GetPeakVolumeIndex (ChannelType.MasterVolume));
+		}
+
 		[Test]
 		public void TestSynchronisedLyricsFrame ()
 		{
